==> mangoautomation-1.0.46.tar.gz: mangoautomation-1.0.46/mangoautomation/exceptions/_error_msg.py <==
# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 错误消息统一管理
# @Time   : 2024-02-01 10:00
# @Author : 毛鹏

ERROR_MSG_0001 = (4001, '')
ERROR_MSG_0002 = (4002, '')
ERROR_MSG_0003 = (4003, '')
ERROR_MSG_0004 = (4004, '')
ERROR_MSG_0005 = (4018, '断言失败，断言输入值是：空字符串、null或不满足函数接受类型')
ERROR_MSG_0006 = (4006, '')
ERROR_MSG_0007 = (4007, '安卓设备被关闭，请检查设备')
ERROR_MSG_0008 = (4008, '浏览器类型不正确，请联系管理员检查')
ERROR_MSG_0009 = (4009, '浏览器路径不正确，请手动设置一个正确的浏览器路径，现在的路径：{}')
ERROR_MSG_0010 = (4010, '浏览器被关闭，请不要手动关闭浏览器')
ERROR_MSG_0011 = (4011, '操作元素【{}】超时，请检查元素可见但是是否可操作或调整定位方式')
ERROR_MSG_0012 = (4012, '操作失败，请检查输入的值是否有空字符串，null或不满足传参的值')
ERROR_MSG_0013 = (
    313, '打开url时超时，分为2个问题：1.启用的浏览器过多，应当减少浏览器并发个数；2.自行查看为啥60秒还未打开：{}')
ERROR_MSG_0014 = (4014, '')
ERROR_MSG_0015 = (4015, '的类型错误，请联系管理员进行排查问题')
ERROR_MSG_0016 = (4016, '')
ERROR_MSG_0017 = (4017, '断言失败： {}')
ERROR_MSG_0018 = (4018, '')
ERROR_MSG_0019 = (4019, '配置了sql断言，但是并没有配置mysql的数据库配置，请检查！')
ERROR_MSG_0020 = (4020, '没有更多的断言方式，请检查是否选择了非该设备类型的元素定位方式')
ERROR_MSG_0021 = (4021, '元素未找到，请检查断言前操作是否正常完成')
ERROR_MSG_0022 = (4022, '页面无此元素，请检查传入的元素是否正确')
ERROR_MSG_0023 = (4023, 'iframe中未找到此元素，请检查元素表达式是否是正确的')
ERROR_MSG_0024 = (4024, '上传文件的元素必须要是input标签中的')
ERROR_MSG_0025 = (4025, '无法元素对应的下标，请检查通过下标获取元素的数是否正确，当前元素个数：{}')
ERROR_MSG_0026 = (4026, '')
ERROR_MSG_0027 = (4027,
                  '您元素的操作内容中没有任何的数据，请检查：1.页面步骤详情中字段->元素操作值是否是空，是空可能是你删除了，也可能是执行器的操作选项没有同步需要点击执行器的同步发送缓存数据；2.元素表达式错误导致查询不到元素；')
ERROR_MSG_0028 = (4028, '')
ERROR_MSG_0029 = (4029, '页面无元素【{}】，表达式：{}')
ERROR_MSG_0030 = (4030, '断言时没有找到元素')
ERROR_MSG_0031 = (4031, '元素未找到准备进行断言获取元素文本类容异常')
ERROR_MSG_0032 = (4032, '元素【{}】的元素表达式定位有多个，或其他元素异常，请检查元素是否可用')
ERROR_MSG_0036 = (4036, '公共参数sql在数据库中查询不到结果，sql：{}')
ERROR_MSG_0038 = (4038, '公共参数的sql_key不是列表')
ERROR_MSG_0040 = (
    340, '设备启动超时！请检查设备是否开启了：文件传输模式、开发者模式、usb调试，开启后请重新连接电脑，设备号：{}')
ERROR_MSG_0041 = (4041, '查找页面元素【{}】时直接失败，报错信息：{}')
ERROR_MSG_0042 = (4042, '实例化对象错误，设备信息是空无法实例化，请联系管理员检查')
ERROR_MSG_0043 = (4043, '元素【{}】可能不存在，报错信息：{}')
ERROR_MSG_0044 = (4044, '元素【{}】可能无法消失，报错信息：{}')
ERROR_MSG_0045 = (4045, '设备启动超时！请检查设备是否已成功连接电脑，设备号：{}')
ERROR_MSG_0046 = (4046, '您要测试的设备中，没有您输入的包名，请检查包名是否正确，或者设备是否安装了这个软件包')
ERROR_MSG_0047 = (4047, '')
ERROR_MSG_0048 = (4048, '选项发生错误，请在执行器点击发送缓存数据，然后重新修改步骤的操作！或联系管理员处理！')
ERROR_MSG_0049 = (4049, 'url格式错误，请检查url或者是选择的测试环境不正确')
ERROR_MSG_0050 = (4050, 'xpath定位未找到元素')
ERROR_MSG_0051 = (4051, '')
ERROR_MSG_0052 = (4052, '元素【{}】 进行断言时发生异常，请检查元素是否可以正常使用')
ERROR_MSG_0053 = (4053, '步骤是断言类型，但是你没有输入断言内容，请查看文档中对元素断言的介绍')
ERROR_MSG_0054 = (4054, '步骤是操作类型，但是你没有输入操作内容，请查看文档中对元素操作的介绍')
ERROR_MSG_0055 = (4055, '您的电脑未安装指定浏览器！')
ERROR_MSG_0056 = (4056, '输入的参数类型不正确，请检查操作输入框的类型是否正确')
ERROR_MSG_0057 = (
    357,
    '创建浏览器的时候失败,如果你开启了视频录制，则需要执行帮助文档中，windows部署的模块最后的安装playwright依赖。如果不是视频录制原因，则请发给管理员！')
ERROR_MSG_0058 = (4058, '电脑可能无网络，或者设置了代理，浏览器无法进行请求！')
ERROR_MSG_0059 = (4059, '输入内容的类型不正确')
ERROR_MSG_0060 = (4060, '请把元素等信息都发给管理员来解决这个报错，报错：{}')
ERROR_MSG_0061 = (4061, '')
ERROR_MSG_0062 = (4062, '请执行：playwright install 命令，安装符合要求的浏览器再运行命令行模式的执行器')

==> mangoautomation-1.0.58.tar.gz: mangoautomation-1.0.58/mangoautomation/exceptions/_error_msg.py <==
# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 错误消息统一管理
# @Time   : 2024-02-01 10:00
# @Author : 毛鹏

ERROR_MSG_0001 = (4001, '')
ERROR_MSG_0002 = (4002, '')
ERROR_MSG_0003 = (4003, '')
ERROR_MSG_0004 = (4004, '')
ERROR_MSG_0005 = (4018, '断言失败，断言输入值是：空字符串、null或不满足函数接受类型')
ERROR_MSG_0006 = (4006, '')
ERROR_MSG_0007 = (4007, '安卓设备被关闭，请检查设备')
ERROR_MSG_0008 = (4008, '浏览器类型不正确，请联系管理员检查')
ERROR_MSG_0009 = (4009, '浏览器路径不正确，请手动设置一个正确的浏览器路径，现在的路径：{}')
ERROR_MSG_0010 = (4010, '浏览器被关闭，请不要手动关闭浏览器')
ERROR_MSG_0011 = (4011, '操作元素【{}】超时，请检查元素可见但是是否可操作或调整定位方式')
ERROR_MSG_0012 = (4012, '操作失败，请检查输入的值是否有空字符串，null或不满足传参的值')
ERROR_MSG_0013 = (
    313, '打开url时超时，分为2个问题：1.启用的浏览器过多，应当减少浏览器并发个数；2.自行查看为啥60秒还未打开：{}')
ERROR_MSG_0014 = (4014, '')
ERROR_MSG_0015 = (4015, '的类型错误，请联系管理员进行排查问题')
ERROR_MSG_0016 = (4016, '')
ERROR_MSG_0017 = (4017, '断言失败： {}')
ERROR_MSG_0018 = (4018, '')
ERROR_MSG_0019 = (4019, '配置了sql断言，但是并没有配置mysql的数据库配置，请检查！')
ERROR_MSG_0020 = (4020, '没有更多的断言方式，请检查是否选择了非该设备类型的元素定位方式')
ERROR_MSG_0021 = (4021, '元素未找到，请检查断言前操作是否正常完成')
ERROR_MSG_0022 = (4022, '页面无此元素，请检查传入的元素是否正确')
ERROR_MSG_0023 = (4023, 'iframe中未找到此元素，请检查元素表达式是否是正确的')
ERROR_MSG_0024 = (4024, '上传文件的元素必须要是input标签中的')
ERROR_MSG_0025 = (4025, '无法元素对应的下标，请检查通过下标获取元素的数是否正确，当前元素个数：{}')
ERROR_MSG_0026 = (4026, '')
ERROR_MSG_0027 = (4027,
                  '您元素的操作内容中没有任何的数据，请检查：1.页面步骤详情中字段->元素操作值是否是空，是空可能是你删除了，也可能是执行器的操作选项没有同步需要点击执行器的同步发送缓存数据；2.元素表达式错误导致查询不到元素；')
ERROR_MSG_0028 = (4028, '')
ERROR_MSG_0029 = (4029, '页面无元素【{}】，表达式：{}')
ERROR_MSG_0030 = (4030, '断言时没有找到元素')
ERROR_MSG_0031 = (4031, '元素未找到准备进行断言获取元素文本类容异常')
ERROR_MSG_0032 = (4032, '元素【{}】的元素表达式定位有多个，或其他元素异常，请检查元素是否可用')
ERROR_MSG_0036 = (4036, '公共参数sql在数据库中查询不到结果，sql：{}')
ERROR_MSG_0038 = (4038, '公共参数的sql_key不是列表')
ERROR_MSG_0040 = (
    340, '设备启动超时！请检查设备是否开启了：文件传输模式、开发者模式、usb调试，开启后请重新连接电脑，设备号：{}')
ERROR_MSG_0041 = (4041, '查找页面元素【{}】时直接失败，报错信息：{}')
ERROR_MSG_0042 = (4042, '实例化对象错误，设备信息是空无法实例化，请联系管理员检查')
ERROR_MSG_0043 = (4043, '元素【{}】可能不存在，报错信息：{}')
ERROR_MSG_0044 = (4044, '元素【{}】可能无法消失，报错信息：{}')
ERROR_MSG_0045 = (4045, '设备启动超时！请检查设备是否已成功连接电脑，设备号：{}')
ERROR_MSG_0046 = (4046, '您要测试的设备中，没有您输入的包名，请检查包名是否正确，或者设备是否安装了这个软件包')
ERROR_MSG_0047 = (4047, '')
ERROR_MSG_0048 = (4048, '选项发生错误，请在执行器点击发送缓存数据，然后重新修改步骤的操作！或联系管理员处理！')
ERROR_MSG_0049 = (4049, 'url格式错误，请检查url或者是选择的测试环境不正确')
ERROR_MSG_0050 = (4050, 'xpath定位未找到元素')
ERROR_MSG_0051 = (4051, '')
ERROR_MSG_0052 = (4052, '元素【{}】 进行断言时发生异常，请检查元素是否可以正常使用')
ERROR_MSG_0053 = (4053, '')
ERROR_MSG_0054 = (4054, '步骤是操作类型，但是你没有输入操作内容，请查看文档中对元素操作的介绍')
ERROR_MSG_0055 = (4055, '您的电脑未安装指定浏览器！')
ERROR_MSG_0056 = (4056, '输入的参数类型不正确，请检查操作输入框的类型是否正确')
ERROR_MSG_0057 = (
    357,
    '创建浏览器的时候失败,如果你开启了视频录制，则需要执行帮助文档中，windows部署的模块最后的安装playwright依赖。如果不是视频录制原因，则请发给管理员！')
ERROR_MSG_0058 = (4058, '电脑可能无网络，或者设置了代理，浏览器无法进行请求！')
ERROR_MSG_0059 = (4059, '输入内容的类型不正确')
ERROR_MSG_0060 = (4060, '请把元素等信息都发给管理员来解决这个报错，报错：{}')
ERROR_MSG_0061 = (4061, '')
ERROR_MSG_0062 = (4062, '请执行：playwright install 命令，安装符合要求的浏览器再运行命令行模式的执行器')
